@@ -2,7 +2,6 @@ from deezer.client import Client
 from deezer.resources import (
     Album,
     Artist,
-    Comment,
     Genre,
     Playlist,
     Radio,
@@ -11,7 +10,7 @@ from deezer.resources import (
     User,
 )
 
-__version__ = "3.1.0"
+__version__ = "4.1.0"
 __all__ = [
     "Client",
     "Resource",
@@ -21,7 +20,6 @@ __all__ = [
     "Playlist",
     "Track",
     "User",
-    "Comment",
     "Radio",
 ]
 
